# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_phylum_global_optspecs
	string join \n c/config= no-config t/timeout= no-check-certificate o/org= v/verbose q/quiet h/help V/version
end

function __fish_phylum_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_phylum_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_phylum_using_subcommand
	set -l cmd (__fish_phylum_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c phylum -n "__fish_phylum_needs_command" -s c -l config -d 'Sets a custom config file' -r -F
complete -c phylum -n "__fish_phylum_needs_command" -s t -l timeout -d 'Set the timeout (in seconds) for requests to the Phylum api' -r
complete -c phylum -n "__fish_phylum_needs_command" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_needs_command" -l no-config -d 'Ignore all configuration files'
complete -c phylum -n "__fish_phylum_needs_command" -l no-check-certificate -d 'Don\'t validate the server certificate when performing api requests'
complete -c phylum -n "__fish_phylum_needs_command" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_needs_command" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_needs_command" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_needs_command" -s V -l version -d 'Print version'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "history" -d 'Return information about historical jobs'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "project" -d 'Manage Phylum projects'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "package" -d 'Retrieve the details of a specific package'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "auth" -d 'Manage authentication, registration, and API keys'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "ping" -d 'Ping the remote system to verify it is available'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "parse" -d 'Parse dependency files and output their packages as JSON'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "analyze" -d 'Submit a request for analysis to the processing system'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "version" -d 'Display application version'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "group" -d 'Interact with user groups'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "init" -d 'Setup a new Phylum project'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "status" -d 'Get Phylum project details'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "find-dependency-files" -d 'Find all lockfile and manifest paths'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "org" -d 'Manage organizations'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "sandbox" -d 'Run an application in a sandbox'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "parse-sandboxed" -d 'Run lockfile generation inside sandbox and write it to STDOUT'
complete -c phylum -n "__fish_phylum_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand history" -s p -l project -d 'Project to be queried' -r
complete -c phylum -n "__fish_phylum_using_subcommand history" -s g -l group -d 'Group to be queried' -r
complete -c phylum -n "__fish_phylum_using_subcommand history" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand history" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand history" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand history" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand history" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -f -a "status" -d 'Get current project information'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -f -a "create" -d 'Create a new project'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -f -a "delete" -d 'Delete a project'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -f -a "update" -d 'Update a project'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -f -a "list" -d 'List all existing projects'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -f -a "link" -d 'Link a repository to a project'
complete -c phylum -n "__fish_phylum_using_subcommand project; and not __fish_seen_subcommand_from status create delete update list link help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from status" -s p -l project -d 'Specify a project to use for analysis' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from status" -s g -l group -d 'Specify a group to use for analysis' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from status" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from status" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from status" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from status" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from create" -s g -l group -d 'Group which will be the owner of the project' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from create" -s r -l repository-url -d 'Repository URL of the project' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from create" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from create" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from create" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from delete" -s g -l group -d 'Group that owns the project' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from delete" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from delete" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from delete" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s i -l project-id -d 'ID of the project to be updated' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s g -l group -d 'Group that owns the project' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s n -l name -d 'New project name' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s r -l repository-url -d 'New repository URL' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s l -l default-label -d 'Default project label' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from update" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from list" -s g -l group -d 'Group to list projects for' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from list" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from list" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from list" -l no-group -d 'Exclude all group projects from the output'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from list" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from link" -s g -l group -d 'Group owning the project' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from link" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from link" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from link" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from link" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "status" -d 'Get current project information'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "create" -d 'Create a new project'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete a project'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "update" -d 'Update a project'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all existing projects'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "link" -d 'Link a repository to a project'
complete -c phylum -n "__fish_phylum_using_subcommand project; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand package" -s f -l filter -d 'Provide a filter used to limit the issues displayed      EXAMPLES:     # Show only issues with severity of at least \'high\'         --filter=high      # Show issues with severity of \'critical\' in the \'author\'     and \'engineering\' domains         --filter=crit,aut,eng ' -r
complete -c phylum -n "__fish_phylum_using_subcommand package" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand package" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand package" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand package" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand package" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "register" -d 'Register a new account'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "login" -d 'Login to an existing account'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "status" -d 'Return the current authentication status'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "set-token" -d 'Set the current authentication token'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "token" -d 'Return the current authentication token'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "list-tokens" -d 'List all tokens associated with the logged-in user'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "revoke-token" -d 'Revoke an API token'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "create-token" -d 'Create a new API token'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and not __fish_seen_subcommand_from register login status set-token token list-tokens revoke-token create-token help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from register" -s n -l token-name -d 'Unique name for the new token that will be created' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from register" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from register" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from register" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from register" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from login" -s n -l token-name -d 'Unique name for the new token that will be created' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from login" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from login" -s r -l reauth -d 'Force a login prompt'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from login" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from login" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from login" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from status" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from status" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from status" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from status" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from set-token" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from set-token" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from set-token" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from set-token" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from token" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from token" -s b -l bearer -d 'Output the short-lived bearer token for the Phylum API'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from token" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from token" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from token" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from list-tokens" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from list-tokens" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from list-tokens" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from list-tokens" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from list-tokens" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from revoke-token" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from revoke-token" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from revoke-token" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from revoke-token" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from create-token" -s e -l expiry -d 'Number of days the token will be valid' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from create-token" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from create-token" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from create-token" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from create-token" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "register" -d 'Register a new account'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "login" -d 'Login to an existing account'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "status" -d 'Return the current authentication status'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "set-token" -d 'Set the current authentication token'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "token" -d 'Return the current authentication token'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "list-tokens" -d 'List all tokens associated with the logged-in user'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "revoke-token" -d 'Revoke an API token'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "create-token" -d 'Create a new API token'
complete -c phylum -n "__fish_phylum_using_subcommand auth; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand ping" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand ping" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand ping" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand ping" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand parse" -s t -l type -d 'Dependency file type used for all lockfiles (default: auto)' -r -f -a "{npm\t'',yarn\t'',pnpm\t'',gem\t'',pip\t'',poetry\t'',pipenv\t'',mvn\t'',gradle\t'',msbuild\t'',nugetlock\t'',gomod\t'',go\t'',cargo\t'',spdx\t'',cyclonedx\t'',auto\t''}"
complete -c phylum -n "__fish_phylum_using_subcommand parse" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand parse" -l skip-sandbox -d 'Run lockfile generation without sandbox protection'
complete -c phylum -n "__fish_phylum_using_subcommand parse" -l no-generation -d 'Disable generation of lockfiles from manifests'
complete -c phylum -n "__fish_phylum_using_subcommand parse" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand parse" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand parse" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s l -l label -d 'Specify a label to use for analysis' -r
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s p -l project -d 'Specify a project to use for analysis' -r
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s g -l group -d 'Specify a group to use for analysis' -r
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s t -l type -d 'Dependency file type used for all lockfiles (default: auto)' -r -f -a "{npm\t'',yarn\t'',pnpm\t'',gem\t'',pip\t'',poetry\t'',pipenv\t'',mvn\t'',gradle\t'',msbuild\t'',nugetlock\t'',gomod\t'',go\t'',cargo\t'',spdx\t'',cyclonedx\t'',auto\t''}"
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s b -l base -d 'Previous list of dependencies for analyzing the delta' -r -F
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -l skip-sandbox -d 'Run lockfile generation without sandbox protection'
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -l no-generation -d 'Disable generation of lockfiles from manifests'
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand analyze" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand version" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand version" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand version" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand version" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -f -a "list" -d 'List all groups the user is a member of'
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -f -a "create" -d 'Create a new group'
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -f -a "delete" -d 'Delete a group'
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -f -a "member" -d 'Manage group members'
complete -c phylum -n "__fish_phylum_using_subcommand group; and not __fish_seen_subcommand_from list create delete member help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from list" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from list" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from list" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from create" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from create" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from create" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from create" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from delete" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from delete" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from delete" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from delete" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -s g -l group -d 'Group to manage the members for' -r
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -f -a "list" -d 'List group members'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -f -a "add" -d 'Add user to group'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -f -a "remove" -d 'Remove user from group'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from member" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all groups the user is a member of'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from help" -f -a "create" -d 'Create a new group'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from help" -f -a "delete" -d 'Delete a group'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from help" -f -a "member" -d 'Manage group members'
complete -c phylum -n "__fish_phylum_using_subcommand group; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand init" -s g -l group -d 'Group which will be the owner of the project' -r
complete -c phylum -n "__fish_phylum_using_subcommand init" -s d -l dependency-file -d 'Project-relative dependency file path' -r
complete -c phylum -n "__fish_phylum_using_subcommand init" -s t -l type -d 'Dependency file type used for all lockfiles (default: auto)' -r -f -a "{npm\t'',yarn\t'',pnpm\t'',gem\t'',pip\t'',poetry\t'',pipenv\t'',mvn\t'',gradle\t'',msbuild\t'',nugetlock\t'',gomod\t'',go\t'',cargo\t'',spdx\t'',cyclonedx\t'',auto\t''}"
complete -c phylum -n "__fish_phylum_using_subcommand init" -s r -l repository-url -d 'Repository URL of the project' -r
complete -c phylum -n "__fish_phylum_using_subcommand init" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand init" -s f -l force -d 'Overwrite existing configurations without confirmation'
complete -c phylum -n "__fish_phylum_using_subcommand init" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand init" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand init" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand status" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand status" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand status" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand status" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand status" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand find-dependency-files" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand find-dependency-files" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand find-dependency-files" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand find-dependency-files" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -f -a "list" -d 'List all organizations the user is a member of'
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -f -a "member" -d 'Manage organization members'
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -f -a "link" -d 'Select an organization as default for all operations'
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -f -a "unlink" -d 'Clear the configured default organization'
complete -c phylum -n "__fish_phylum_using_subcommand org; and not __fish_seen_subcommand_from list member link unlink help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from list" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from list" -s j -l json -d 'Produce output in json format (default: false)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from list" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from list" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from list" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from member" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from member" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from member" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from member" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from member" -f -a "list" -d 'List organization members'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from member" -f -a "add" -d 'Add user to organization'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from member" -f -a "remove" -d 'Remove user from organization'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from member" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from link" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from link" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from link" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from unlink" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from unlink" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from unlink" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from unlink" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from help" -f -a "list" -d 'List all organizations the user is a member of'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from help" -f -a "member" -d 'Manage organization members'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from help" -f -a "link" -d 'Select an organization as default for all operations'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from help" -f -a "unlink" -d 'Clear the configured default organization'
complete -c phylum -n "__fish_phylum_using_subcommand org; and __fish_seen_subcommand_from help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -l allow-read -d 'Add filesystem read sandbox exception' -r -F
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -l allow-write -d 'Add filesystem write sandbox exception' -r -F
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -l allow-run -d 'Add filesystem execute sandbox exception' -r -F
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -l allow-env -d 'Add environment variable access sandbox exception' -r
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -l allow-net -d 'Add network access sandbox exception'
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -l strict -d 'Do not add any default sandbox exceptions'
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand sandbox" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand parse-sandboxed" -l type -d 'Dependency file type used (default: auto)' -r -f -a "{npm\t'',yarn\t'',pnpm\t'',gem\t'',pip\t'',poetry\t'',pipenv\t'',mvn\t'',gradle\t'',msbuild\t'',nugetlock\t'',gomod\t'',go\t'',cargo\t'',spdx\t'',cyclonedx\t'',auto\t''}"
complete -c phylum -n "__fish_phylum_using_subcommand parse-sandboxed" -s o -l org -d 'Phylum organization' -r
complete -c phylum -n "__fish_phylum_using_subcommand parse-sandboxed" -l generate-lockfile -d 'Whether lockfile generation should be performed'
complete -c phylum -n "__fish_phylum_using_subcommand parse-sandboxed" -l skip-sandbox -d 'Skip sandbox initialization'
complete -c phylum -n "__fish_phylum_using_subcommand parse-sandboxed" -s v -l verbose -d 'Increase the level of verbosity (the maximum is -vvv)'
complete -c phylum -n "__fish_phylum_using_subcommand parse-sandboxed" -s q -l quiet -d 'Reduce the level of verbosity (the maximum is -qq)'
complete -c phylum -n "__fish_phylum_using_subcommand parse-sandboxed" -s h -l help -d 'Print help'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "history" -d 'Return information about historical jobs'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "project" -d 'Manage Phylum projects'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "package" -d 'Retrieve the details of a specific package'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "auth" -d 'Manage authentication, registration, and API keys'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "ping" -d 'Ping the remote system to verify it is available'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "parse" -d 'Parse dependency files and output their packages as JSON'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "analyze" -d 'Submit a request for analysis to the processing system'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "version" -d 'Display application version'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "group" -d 'Interact with user groups'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "init" -d 'Setup a new Phylum project'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "status" -d 'Get Phylum project details'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "find-dependency-files" -d 'Find all lockfile and manifest paths'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "org" -d 'Manage organizations'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "sandbox" -d 'Run an application in a sandbox'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "parse-sandboxed" -d 'Run lockfile generation inside sandbox and write it to STDOUT'
complete -c phylum -n "__fish_phylum_using_subcommand help; and not __fish_seen_subcommand_from history project package auth ping parse analyze version group init status find-dependency-files org sandbox parse-sandboxed help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "status" -d 'Get current project information'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "create" -d 'Create a new project'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "delete" -d 'Delete a project'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "update" -d 'Update a project'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "list" -d 'List all existing projects'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from project" -f -a "link" -d 'Link a repository to a project'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "register" -d 'Register a new account'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "login" -d 'Login to an existing account'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "status" -d 'Return the current authentication status'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "set-token" -d 'Set the current authentication token'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "token" -d 'Return the current authentication token'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "list-tokens" -d 'List all tokens associated with the logged-in user'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "revoke-token" -d 'Revoke an API token'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from auth" -f -a "create-token" -d 'Create a new API token'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from group" -f -a "list" -d 'List all groups the user is a member of'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from group" -f -a "create" -d 'Create a new group'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from group" -f -a "delete" -d 'Delete a group'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from group" -f -a "member" -d 'Manage group members'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from org" -f -a "list" -d 'List all organizations the user is a member of'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from org" -f -a "member" -d 'Manage organization members'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from org" -f -a "link" -d 'Select an organization as default for all operations'
complete -c phylum -n "__fish_phylum_using_subcommand help; and __fish_seen_subcommand_from org" -f -a "unlink" -d 'Clear the configured default organization'
